A tool for reading/writing PCAPNG network packet capture files
=======================================================================

Alan Thompson, Brocade
athomps@brocade.com

Please see the IETF document `PCAP Next Generation (pcapng) Capture File Format <https://goo.gl/ISj1QY/>`_

Please also see the `project home page <https://gitlab.com/netdev-americas/pcapng/>`_

